@@ -1,6 +1,6 @@
 # 2022.5.28  
 import re, math #torch
-from transformers import pipeline
+from transformers import pipeline #None of PyTorch, TensorFlow >= 2.0, or Flax have been found. Models won't be available and only tokenizers, configuration and file/data utilities can be used.
 
 token_split	= lambda sent: re.findall(r"[\w']+|[.,!?;]", sent) # return list
 def common_perc(snt="She has ready.", trans="She is ready."): 
